# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
	imports =
		[ # Include the results of the hardware scan.
			./hardware-configuration.nix
		];

	# Set your time zone.
	time.timeZone = "America/New_York";

	# Configure suspend to disk
	systemd.sleep.extraConfig = ''
	SuspendState=disk
	SuspendMode=suspend
	HibernateMode=platform shutdown
	'';

	##############
	# NETWORKING #
	##############
	networking.useDHCP = false;
	networking.networkmanager.enable = true;

	networking.hostName = "loft"; # Define your hostname.
	networking.firewall.enable = false;

	home-manager = {
    users.michael = import ../../user/environments/nixos/home.nix pkgs;
    useGlobalPkgs = true;
  };

	# Configure network proxy if necessary
	# networking.proxy.default = "http://user:password@proxy:port/";
	# networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

	# Select internationalisation properties.
	# i18n.defaultLocale = "en_US.UTF-8";
	# console = {
	#   font = "Lat2-Terminus16";
	#   keyMap = "us";
	# };
	
	# Configure keymap in X11
	# services.xserver.layout = "us";
	# services.xserver.xkbOptions = "eurosign:e";

	# Enable touchpad support (enabled default in most desktopManager).
	# services.xserver.libinput.enable = true;

	programs.adb.enable = true;

	programs.zsh.enable = true;

	users.defaultUserShell = pkgs.zsh;
	# Define a user account. Don't forget to set a password with ‘passwd’.
	users.users.michael = {
		 isNormalUser = true;
		 description = "Michael Thomas";
		 extraGroups = [ "wheel" "docker" "networkmanager" "adbusers" ]; # Enable ‘sudo’ for the user.
		 shell = pkgs.zsh;
	 };

	# List packages installed in system profile. To search, run:
	# $ nix search wget
	environment.systemPackages = with pkgs; [
		wget micro
		google-chrome
		gnome3.gnome-tweaks
		gnomeExtensions.gsconnect
	];

	# Some programs need SUID wrappers, can be configured further or are
	# started in user sessions.
	# programs.mtr.enable = true;
	# programs.gnupg.agent = {
	#   enable = true;
	#   enableSSHSupport = true;
	# };

	# List services that you want to enable:

	# Enable the OpenSSH daemon.
	# services.openssh.enable = true;

	# Open ports in the firewall.
	# networking.firewall.allowedTCPPorts = [ ... ];
	# networking.firewall.allowedUDPPorts = [ ... ];
	# Or disable the firewall altogether.
	# networking.firewall.enable = false;

	# This value determines the NixOS release from which the default
	# settings for stateful data, like file locations and database versions
	# on your system were taken. It‘s perfectly fine and recommended to leave
	# this value at the release version of the first install of this system.
	# Before changing this value read the documentation for this option
	# (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
	system.stateVersion = "20.09"; # Did you read the comment?

}
